@@ -118,7 +118,7 @@ def init_openmodule(config, sentry=True, logging=True, dsgvo=True,
     return _core_thread
 
 
-def core():
+def core() -> OpenModuleCore:
     return _core_thread
 
 
@@ -126,10 +126,23 @@ def shutdown_openmodule():
     global _core_thread
     assert _core_thread, "core thread is not running, did you call init_openmodule(...)?"
 
-    if _core_thread.database:
-        _core_thread.database.shutdown()
-
-    _core_thread.context.term()
-    _core_thread.join()
-
+    current_cure = _core_thread
     _core_thread = None
+
+    shutdown_done = threading.Event()
+
+    def last_will():
+        if not shutdown_done.wait(timeout=1):
+            os._exit(99)
+
+    if not (current_cure.config.TESTING or current_cure.config.DEBUG):
+        last_will_thread = threading.Thread(target=last_will)
+        last_will_thread.setDaemon(True)
+        last_will_thread.start()
+
+    if current_cure.database:
+        current_cure.database.shutdown()
+
+    current_cure.context.term()
+    current_cure.join()
+    shutdown_done.set()
