@@ -2,12 +2,13 @@ import logging
 import time
 from collections import namedtuple
 from enum import Enum
-from typing import Optional, Dict, Callable
+from typing import Optional, Dict, Callable, Any
 
 from openmodule.models import ZMQMessage, OpenModuleModel
 
 from typing import TYPE_CHECKING
-if TYPE_CHECKING: # pragma: no cover
+
+if TYPE_CHECKING:  # pragma: no cover
     from openmodule.core import OpenModuleCore
 
 
@@ -30,6 +31,10 @@ class HealthPongMessage(ZMQMessage):
     pong: HealthPongPayload
 
 
+class HealthPingMessage(ZMQMessage):
+    type: str = "ping"
+
+
 startup = time.time()
 
 HealthResult = namedtuple("HealthResult", "status,message,meta")
@@ -54,26 +59,25 @@ class Healthz:
         self.core = core
         self.log = logging.getLogger(self.__class__.__name__)
 
-    def process_message(self, message):
-        if message is not None and "ping" in message:
-            try:
-                result = self.health_handler()
-            except Exception as e:
-                self.log.exception(e)
-                result = health_error("internal error in health routine")
+    def process_message(self, _: HealthPingMessage):
+        try:
+            result = self.health_handler()
+        except Exception as e:
+            self.log.exception(e)
+            result = health_error("internal error in health routine")
 
-            if not isinstance(result, HealthResult):
-                self.log.error(f"invalid return type '{type(result)}' from health handler, "
-                               f"expected HealthResult")
-                result = health_error("internal error in health routine")
+        if not isinstance(result, HealthResult):
+            self.log.error(f"invalid return type '{type(result)}' from health handler, "
+                           f"expected HealthResult")
+            result = health_error("internal error in health routine")
 
-            response = HealthPongMessage(
+        response = HealthPongMessage(
+            name=self.core.config.NAME,
+            pong=dict(
+                status=result.status,
+                message=result.message,
+                version=self.core.config.VERSION,
                 name=self.core.config.NAME,
-                pong=dict(
-                    status=result.status,
-                    message=result.message,
-                    version=self.core.config.VERSION,
-                    name=self.core.config.NAME,
-                    startup=startup,
-                    meta=result.meta or {}))
-            self.core.publish(response, b"healthz")
+                startup=startup,
+                meta=result.meta or {}))
+        self.core.publish(response, b"healthz")
