@@ -58,3 +58,6 @@ class Direction(str, Enum):
 class Gateway(OpenModuleModel):
     gate: str = ""
     direction: Direction = ""
+
+    def __str__(self):
+        return f"{self.gate}/{self.direction}"
