@@ -57,7 +57,7 @@ def init_sentry(core: 'OpenModuleCore', extras=None, **kwargs):
             for key, value in extras.items():
                 scope.set_extra(key, value)
     else:
-        core.log.info("not activating sentry because version is unknown")
+        core.log.info("not activating sentry in debug or test mode")
 
 
 def should_activate_sentry(config) -> bool:
@@ -67,7 +67,7 @@ def should_activate_sentry(config) -> bool:
     :param config: current configuration
     :return: bool
     """
-    if config.VERSION == "unknown":
+    if config.DEBUG or config.TESTING:
         return False
     return True
 
