@@ -14,6 +14,7 @@ class ConnectionStatusListener:
     on_connect: EventListener
     on_disconnect: EventListener
     connected: bool = True
+    _first_message: bool = True
 
     def __init__(self, dispatcher: MessageDispatcher):
         self.log = logging.getLogger(self.__class__.__name__)
@@ -26,7 +27,8 @@ class ConnectionStatusListener:
 
     def process_connection_status(self, message: ConnectionStatusMessage):
         new_connected = message.connected
-        if new_connected != self.connected:
+        if new_connected != self.connected or self._first_message:
+            self._first_message = False
             self.connected = new_connected
             if new_connected:
                 self.on_connect()
