@@ -12,6 +12,7 @@ from types import SimpleNamespace
 from openmodule import config
 from openmodule.config import validate_config_module
 from openmodule.models import OpenModuleModel
+from openmodule_test.core import OpenModuleCoreTestMixin
 from openmodule_test.files import temp_file
 
 
@@ -224,9 +225,35 @@ class LegacyConfigSupportTest(EnvTestCase):
             fake_config.NAME = "test"
             fake_config.RESOURCE = "test"
             fake_config.VERSION = "test"
+            fake_config.DEBUG = False
+            fake_config.TESTING = True
             fake_config.BROKER_PUB_PORT = "10000"
             validate_config_module(fake_config)
 
-            self.assertEqual(1, len(w))
-            self.assertTrue(issubclass(w[0].category, DeprecationWarning))
-            self.assertIn("BROKER_PUB", str(w[0].message))
+        self.assertEqual(1, len(w))
+        self.assertTrue(issubclass(w[0].category, DeprecationWarning))
+        self.assertIn("BROKER_PUB", str(w[0].message))
+
+
+class MinimalConfig:
+    TEST = "abc"
+    BEST = "best"
+
+
+class BaseConfigTest(OpenModuleCoreTestMixin):
+    config_kwargs = dict(TEST="asdf", RESOURCE="arivo", NAME="abc")
+    base_config = MinimalConfig
+
+    def test_config(self):
+        # assert fake config is used
+        self.assertIsNotNone(self.core.config.BROKER_PUB)
+
+        # assert init_kwargs overwrite base config
+        self.assertEqual(self.core.config.TEST, "asdf")
+
+        # assert init_kwargs overwrite fake config
+        self.assertEqual(self.core.config.RESOURCE, "arivo")
+        self.assertEqual(self.core.config.NAME, "abc")
+
+        # assert minimal config
+        self.assertEqual(self.core.config.BEST, "best")
