@@ -21,7 +21,8 @@ class OpenModuleCoreTest(AlertTestMixin, HealthTestMixin, TestCase):
             shutdown_openmodule()
 
     def test_core_sentry_error_logging(self):
-        init_openmodule(self.zmq_config())
+        # sentry is not active during unittests / debug
+        init_openmodule(self.zmq_config(DEBUG=False, TESTING=False))
         self.wait_for_health()
 
         try:
